require 'spec_helper'
require 'interfaces/ses'
require 'models/email'
require 'logger/logger'

describe 'SES' do

  let(:email) { MailHandler::Models::Email.new({}) }

  before :each do
    @ses = double

    allow(AWS::SES::Base).to receive(:new).and_return(@ses)
    allow(@ses).to receive(:quota).and_return(true)

    MailHandler::SES.setup({})
  end

  describe '#send_mail' do
    subject { MailHandler::SES.mailer }

    let(:success) { double(error?: false) }

    let(:failure) { double(error?: true, error: 'Error String', code: 400) }

    it 'handles successfully sent mail' do
      allow(@ses).to receive(:send_email)
        .with(email.to_h).and_return(success)

      expect(MailHandler::Logger).to receive(:success).once
      expect(subject.send_mail(email).error?).to eq false
    end

    it 'handles failures while sending mail' do
      allow(@ses).to receive(:send_email)
        .with(email.to_h).and_return(failure)

      expect(MailHandler::Logger).to receive(:error).once
      expect(subject.send_mail(email).error?).to eq true
    end
  end
end
