require 'spec_helper'
require 'mailhandler'

describe 'MailHandler' do
  before { @handler = MailHandler::Handler.new }

  describe '#do_work' do
    context 'when no messages' do
      before(:each) { allow(@handler).to receive(:messages) { [] } }

      it 'should go straight for sleep' do
        expect(@handler).to receive(:sleep).with(1) { true }
        @handler.do_work
      end
    end

    context 'when messages' do
      let(:message) { double }
      let(:email) { double }

      before(:each) do
        allow(@handler).to receive(:messages) { [message] }
        allow(@handler).to receive(:email_from).with(message) { email }
      end

      it 'should try to send the messages' do
        expect(@handler).to receive(:send).with(email)
        @handler.do_work
      end

      it 'should delete the messages unless errors' do
        expect(@handler).to receive(:send) { double(:error? => false) }
        expect(message).to receive(:delete)
        @handler.do_work
      end

      it 'should not delete the messages if errors' do
        expect(@handler).to receive(:send) { double(:error? => true) }
        expect(message).not_to receive(:delete)
        @handler.do_work
      end
    end
  end
end
